package v1beta1

import "k8s.io/api/storagemigration/v1beta1"

Index

Constants

const GroupName = "storagemigration.k8s.io"

GroupName is the group name use in this package

Variables

var (
	ErrInvalidLengthGenerated        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowGenerated          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupGenerated = fmt.Errorf("proto: unexpected end of group")
)
var (
	SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes)

	AddToScheme = localSchemeBuilder.AddToScheme
)
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1beta1"}

SchemeGroupVersion is group version used to register these objects

Functions

func Kind

func Kind(kind string) schema.GroupKind

Kind takes an unqualified kind and returns a Group qualified GroupKind

func Resource

func Resource(resource string) schema.GroupResource

Resource takes an unqualified resource and returns a Group qualified GroupResource

Types

type MigrationConditionType

type MigrationConditionType string
const (
	// Indicates that the migration is running.
	MigrationRunning MigrationConditionType = "Running"
	// Indicates that the migration has completed successfully.
	MigrationSucceeded MigrationConditionType = "Succeeded"
	// Indicates that the migration has failed.
	MigrationFailed MigrationConditionType = "Failed"
)

type StorageVersionMigration

type StorageVersionMigration struct {
	metav1.TypeMeta `json:",inline"`
	// Standard object metadata.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	// +optional
	metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
	// Specification of the migration.
	// +optional
	Spec StorageVersionMigrationSpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
	// Status of the migration.
	// +optional
	Status StorageVersionMigrationStatus `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
}

StorageVersionMigration represents a migration of stored data to the latest storage version.

func (*StorageVersionMigration) APILifecycleDeprecated

func (in *StorageVersionMigration) APILifecycleDeprecated() (major, minor int)

APILifecycleDeprecated is an autogenerated function, returning the release in which the API struct was or will be deprecated as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:deprecated" tags in types.go or "k8s:prerelease-lifecycle-gen:introduced" plus three minor.

func (*StorageVersionMigration) APILifecycleIntroduced

func (in *StorageVersionMigration) APILifecycleIntroduced() (major, minor int)

APILifecycleIntroduced is an autogenerated function, returning the release in which the API struct was introduced as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:introduced" tags in types.go.

func (*StorageVersionMigration) APILifecycleRemoved

func (in *StorageVersionMigration) APILifecycleRemoved() (major, minor int)

APILifecycleRemoved is an autogenerated function, returning the release in which the API is no longer served as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:removed" tags in types.go or "k8s:prerelease-lifecycle-gen:deprecated" plus three minor.

func (*StorageVersionMigration) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StorageVersionMigration.

func (*StorageVersionMigration) DeepCopyInto

func (in *StorageVersionMigration) DeepCopyInto(out *StorageVersionMigration)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*StorageVersionMigration) DeepCopyObject

func (in *StorageVersionMigration) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*StorageVersionMigration) Marshal

func (m *StorageVersionMigration) Marshal() (dAtA []byte, err error)

func (*StorageVersionMigration) MarshalTo

func (m *StorageVersionMigration) MarshalTo(dAtA []byte) (int, error)

func (*StorageVersionMigration) MarshalToSizedBuffer

func (m *StorageVersionMigration) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (StorageVersionMigration) OpenAPIModelName

func (in StorageVersionMigration) OpenAPIModelName() string

OpenAPIModelName returns the OpenAPI model name for this type.

func (*StorageVersionMigration) Reset

func (m *StorageVersionMigration) Reset()

func (*StorageVersionMigration) Size

func (m *StorageVersionMigration) Size() (n int)

func (*StorageVersionMigration) String

func (this *StorageVersionMigration) String() string

func (StorageVersionMigration) SwaggerDoc

func (StorageVersionMigration) SwaggerDoc() map[string]string

func (*StorageVersionMigration) Unmarshal

func (m *StorageVersionMigration) Unmarshal(dAtA []byte) error

type StorageVersionMigrationList

type StorageVersionMigrationList struct {
	metav1.TypeMeta `json:",inline"`

	// Standard list metadata
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	// +optional
	metav1.ListMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
	// Items is the list of StorageVersionMigration
	Items []StorageVersionMigration `json:"items" protobuf:"bytes,2,rep,name=items"`
}

StorageVersionMigrationList is a collection of storage version migrations.

func (*StorageVersionMigrationList) APILifecycleDeprecated

func (in *StorageVersionMigrationList) APILifecycleDeprecated() (major, minor int)

APILifecycleDeprecated is an autogenerated function, returning the release in which the API struct was or will be deprecated as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:deprecated" tags in types.go or "k8s:prerelease-lifecycle-gen:introduced" plus three minor.

func (*StorageVersionMigrationList) APILifecycleIntroduced

func (in *StorageVersionMigrationList) APILifecycleIntroduced() (major, minor int)

APILifecycleIntroduced is an autogenerated function, returning the release in which the API struct was introduced as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:introduced" tags in types.go.

func (*StorageVersionMigrationList) APILifecycleRemoved

func (in *StorageVersionMigrationList) APILifecycleRemoved() (major, minor int)

APILifecycleRemoved is an autogenerated function, returning the release in which the API is no longer served as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:removed" tags in types.go or "k8s:prerelease-lifecycle-gen:deprecated" plus three minor.

func (*StorageVersionMigrationList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StorageVersionMigrationList.

func (*StorageVersionMigrationList) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*StorageVersionMigrationList) DeepCopyObject

func (in *StorageVersionMigrationList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*StorageVersionMigrationList) Marshal

func (m *StorageVersionMigrationList) Marshal() (dAtA []byte, err error)

func (*StorageVersionMigrationList) MarshalTo

func (m *StorageVersionMigrationList) MarshalTo(dAtA []byte) (int, error)

func (*StorageVersionMigrationList) MarshalToSizedBuffer

func (m *StorageVersionMigrationList) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (StorageVersionMigrationList) OpenAPIModelName

func (in StorageVersionMigrationList) OpenAPIModelName() string

OpenAPIModelName returns the OpenAPI model name for this type.

func (*StorageVersionMigrationList) Reset

func (m *StorageVersionMigrationList) Reset()

func (*StorageVersionMigrationList) Size

func (m *StorageVersionMigrationList) Size() (n int)

func (*StorageVersionMigrationList) String

func (this *StorageVersionMigrationList) String() string

func (StorageVersionMigrationList) SwaggerDoc

func (StorageVersionMigrationList) SwaggerDoc() map[string]string

func (*StorageVersionMigrationList) Unmarshal

func (m *StorageVersionMigrationList) Unmarshal(dAtA []byte) error

type StorageVersionMigrationSpec

type StorageVersionMigrationSpec struct {
	// The resource that is being migrated. The migrator sends requests to
	// the endpoint serving the resource.
	// Immutable.
	Resource metav1.GroupResource `json:"resource" protobuf:"bytes,1,opt,name=resource"`
}

Spec of the storage version migration.

func (*StorageVersionMigrationSpec) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StorageVersionMigrationSpec.

func (*StorageVersionMigrationSpec) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*StorageVersionMigrationSpec) Marshal

func (m *StorageVersionMigrationSpec) Marshal() (dAtA []byte, err error)

func (*StorageVersionMigrationSpec) MarshalTo

func (m *StorageVersionMigrationSpec) MarshalTo(dAtA []byte) (int, error)

func (*StorageVersionMigrationSpec) MarshalToSizedBuffer

func (m *StorageVersionMigrationSpec) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (StorageVersionMigrationSpec) OpenAPIModelName

func (in StorageVersionMigrationSpec) OpenAPIModelName() string

OpenAPIModelName returns the OpenAPI model name for this type.

func (*StorageVersionMigrationSpec) Reset

func (m *StorageVersionMigrationSpec) Reset()

func (*StorageVersionMigrationSpec) Size

func (m *StorageVersionMigrationSpec) Size() (n int)

func (*StorageVersionMigrationSpec) String

func (this *StorageVersionMigrationSpec) String() string

func (StorageVersionMigrationSpec) SwaggerDoc

func (StorageVersionMigrationSpec) SwaggerDoc() map[string]string

func (*StorageVersionMigrationSpec) Unmarshal

func (m *StorageVersionMigrationSpec) Unmarshal(dAtA []byte) error

type StorageVersionMigrationStatus

type StorageVersionMigrationStatus struct {
	// The latest available observations of the migration's current state.
	// +patchMergeKey=type
	// +patchStrategy=merge
	// +listType=map
	// +listMapKey=type
	// +optional
	Conditions []metav1.Condition `json:"conditions,omitempty" patchStrategy:"merge" patchMergeKey:"type" protobuf:"bytes,1,rep,name=conditions"`
	// ResourceVersion to compare with the GC cache for performing the migration.
	// This is the current resource version of given group, version and resource when
	// kube-controller-manager first observes this StorageVersionMigration resource.
	ResourceVersion string `json:"resourceVersion,omitempty" protobuf:"bytes,2,opt,name=resourceVersion"`
}

Status of the storage version migration.

func (*StorageVersionMigrationStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StorageVersionMigrationStatus.

func (*StorageVersionMigrationStatus) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*StorageVersionMigrationStatus) Marshal

func (m *StorageVersionMigrationStatus) Marshal() (dAtA []byte, err error)

func (*StorageVersionMigrationStatus) MarshalTo

func (m *StorageVersionMigrationStatus) MarshalTo(dAtA []byte) (int, error)

func (*StorageVersionMigrationStatus) MarshalToSizedBuffer

func (m *StorageVersionMigrationStatus) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (StorageVersionMigrationStatus) OpenAPIModelName

func (in StorageVersionMigrationStatus) OpenAPIModelName() string

OpenAPIModelName returns the OpenAPI model name for this type.

func (*StorageVersionMigrationStatus) Reset

func (m *StorageVersionMigrationStatus) Reset()

func (*StorageVersionMigrationStatus) Size

func (m *StorageVersionMigrationStatus) Size() (n int)

func (*StorageVersionMigrationStatus) String

func (this *StorageVersionMigrationStatus) String() string

func (StorageVersionMigrationStatus) SwaggerDoc

func (StorageVersionMigrationStatus) SwaggerDoc() map[string]string

func (*StorageVersionMigrationStatus) Unmarshal

func (m *StorageVersionMigrationStatus) Unmarshal(dAtA []byte) error

Source Files

doc.go generated.pb.go register.go types.go types_swagger_doc_generated.go zz_generated.deepcopy.go zz_generated.model_name.go zz_generated.prerelease-lifecycle.go

Version
v0.36.0-alpha.1
Published
Feb 6, 2026
Platform
linux/amd64
Imports
8 packages
Last checked
4 minutes ago

Tools for package owners.